@@ -3,7 +3,8 @@ if ($("#checked").val() != "1") $('[name="questSubmit"]').attr('disabled','disab
 var qname = document.getElementById("qname").value;
 var min = document.getElementById("min").value;
 var max = document.getElementById("max").value;
-
+// var betragins = append("<br />").text("INTERVIEWER: Mögliche Eingaben zw. '.$min.' und '.$max.'.").css("background-color", "yellow");
+// var waehrins = append("<br />").append(" Auch Angaben in einer anderen Währung aufnehmen.");
 var startnode = document.getElementById("ct_"+qname+"_1");
 //alert("RTEST");
 //startnode.parentNode.parentNode.parentNode.appendChild(document.getElementById('treuro'));
@@ -189,7 +190,7 @@ button.onclick = function() {
     }
     if (values["kategorie"] == "" && values["waehrung"] == "") {
         checkinput = 0;
-        betragges = "Wählen Sie ein Währung aus!";
+        betragges = "Wählen Sie eine Währung aus!";
     }
     if (((values["betragka"]==1 || values["betragwn"]==1) && (values["bereichka"]==1 || values["bereichwn"]==1)) &&
         (values["kategorie"] == ""))  {
@@ -220,16 +221,20 @@ button.onclick = function() {
         betragwaehr = $( "select[name='waehrung'] option:selected" ).text();
         if (values["waehrung"] == 16)  betragwaehr = $("#waehrop").val();
         var varify = false;
+		var neg = '';
         var quest =  "Ist das richtig (OK)?";
         //BETRAG GENANNT
         if (parseInt($("#betragop").val()) <= max && parseInt($("#betragop").val()) >= min && $("#betragop").val() != "") {
             betragnr = parseInt($("#betragop").val());
+            if (betragnr<0) {
+				betragnr = betragnr * (-1);
+				neg = '-';
+			}
             betragstrg = betragnr.toString();
-            //if (parseInt($("#betragop").val()<0)
-            console.log("TEST4.2 "+betragnr+" "+betragstrg.length);
-            if (betragstrg.length > 6)  betragtxt = betragstrg.substring(0, betragstrg.length-6)+"."+betragstrg.substring(betragstrg.length-6, betragstrg.length-3)+"."+betragstrg.substring(betragstrg.length-3, betragstrg.length);
-            else if (betragstrg.length > 3) betragtxt = betragstrg.substring(0, betragstrg.length-3)+"."+betragstrg.substring(betragstrg.length-3, betragstrg.length);
-            else betragtxt = betragstrg;
+            console.log("TEST4.2 ("+neg+")"+betragnr+" "+betragstrg.length);
+            if (betragstrg.length > 6)  betragtxt = neg+betragstrg.substring(0, betragstrg.length-6)+"."+betragstrg.substring(betragstrg.length-6, betragstrg.length-3)+"."+betragstrg.substring(betragstrg.length-3, betragstrg.length);
+            else if (betragstrg.length > 3) betragtxt = neg+betragstrg.substring(0, betragstrg.length-3)+"."+betragstrg.substring(betragstrg.length-3, betragstrg.length);
+            else betragtxt = neg+betragstrg;
 
             var betragges = "Sie haben angegeben, dass der Betrag bei "+betragwaehr+" "+betragtxt+" liegt.";
             // var betragges = "Sie haben angegeben, dass der Betrag bei "+betragwaehr+" "+betragnr+" (in Worten "+betragtxt+") liegt.";
@@ -237,34 +242,51 @@ button.onclick = function() {
         //BEREICH GENANNT
         else if (parseInt($("#oberop").val()) <= max && parseInt($("#oberop").val()) >= min && parseInt($("#unterop").val()) <= max && parseInt($("#unterop").val()) >= min && $("#oberop").val() != "" && $("#unterop").val() != "") {
             betragnr = parseInt($("#unterop").val());
+            if (betragnr<0) {
+				betragnr = betragnr * (-1);
+				neg = '-';
+			}
             betragstrg = betragnr.toString();
-            if (betragstrg.length > 6)  betragtxt = betragstrg.substring(0, betragstrg.length-6)+"."+betragstrg.substring(betragstrg.length-6, betragstrg.length-3)+"."+betragstrg.substring(betragstrg.length-3, betragstrg.length);
-            else if (betragstrg.length > 3) betragtxt = betragstrg.substring(0, betragstrg.length-3)+"."+betragstrg.substring(betragstrg.length-3, betragstrg.length);
-            else betragtxt = betragstrg;
-            betragnr = parseInt($("#oberop").val());
+            if (betragstrg.length > 6)  betragtxt = neg+betragstrg.substring(0, betragstrg.length-6)+"."+betragstrg.substring(betragstrg.length-6, betragstrg.length-3)+"."+betragstrg.substring(betragstrg.length-3, betragstrg.length);
+            else if (betragstrg.length > 3) betragtxt = neg+betragstrg.substring(0, betragstrg.length-3)+"."+betragstrg.substring(betragstrg.length-3, betragstrg.length);
+            else betragtxt = neg+betragstrg;
+            neg = '';
+			betragnr = parseInt($("#oberop").val());
+            if (betragnr<0) {
+				betragnr = betragnr * (-1);
+				neg = '-';
+			}
             betragstrg = betragnr.toString();
-            if (betragstrg.length > 6)  betragtxt = betragtxt +" und "+ betragstrg.substring(0, betragstrg.length-6)+"."+betragstrg.substring(betragstrg.length-6, betragstrg.length-3)+"."+betragstrg.substring(betragstrg.length-3, betragstrg.length);
-            else if (betragstrg.length > 3) betragtxt =  betragtxt +" und "+ betragstrg.substring(0, betragstrg.length-3)+"."+betragstrg.substring(betragstrg.length-3, betragstrg.length);
-            else betragtxt =  betragtxt +" und "+ betragstrg;
+            if (betragstrg.length > 6)  betragtxt = betragtxt +" und "+ neg+betragstrg.substring(0, betragstrg.length-6)+"."+betragstrg.substring(betragstrg.length-6, betragstrg.length-3)+"."+betragstrg.substring(betragstrg.length-3, betragstrg.length);
+            else if (betragstrg.length > 3) betragtxt =  betragtxt +" und "+ neg+betragstrg.substring(0, betragstrg.length-3)+"."+betragstrg.substring(betragstrg.length-3, betragstrg.length);
+            else betragtxt =  betragtxt +" und "+ neg+betragstrg;
             // betragnr = $("#unterop").val()+" und "+$("#oberop").val();
             var betragges = "Sie haben angegeben, dass der Betrag schätzungsweise zwischen "+betragwaehr+" "+betragtxt+" liegt.";
         }
         //NUR OBERGRENZE GENANNT
         else if (parseInt($("#oberop").val()) <= max && parseInt($("#oberop").val()) >= min && $("#oberop").val() != "") {
             betragnr = parseInt($("#oberop").val());
+            if (betragnr<0) {
+				betragnr = betragnr * (-1);
+				neg = '-';
+			}
             betragstrg = betragnr.toString();
-            if (betragstrg.length > 6)  betragtxt = betragstrg.substring(0, betragstrg.length-6)+"."+betragstrg.substring(betragstrg.length-6, betragstrg.length-3)+"."+betragstrg.substring(betragstrg.length-3, betragstrg.length);
-            else if (betragstrg.length > 3) betragtxt = betragstrg.substring(0, betragstrg.length-3)+"."+betragstrg.substring(betragstrg.length-3, betragstrg.length);
-            else betragtxt = betragstrg;
+            if (betragstrg.length > 6)  betragtxt = neg+betragstrg.substring(0, betragstrg.length-6)+"."+betragstrg.substring(betragstrg.length-6, betragstrg.length-3)+"."+betragstrg.substring(betragstrg.length-3, betragstrg.length);
+            else if (betragstrg.length > 3) betragtxt = neg+betragstrg.substring(0, betragstrg.length-3)+"."+betragstrg.substring(betragstrg.length-3, betragstrg.length);
+            else betragtxt = neg+betragstrg;
             var betragges = "Sie haben angegeben, dass der Betrag schätzungsweise unter "+betragwaehr+" "+betragtxt+" liegt.";
         }
         //NUR UNTERGRENZE GENANNT
         else if (parseInt($("#unterop").val()) <= max && parseInt($("#unterop").val()) >= min && $("#unterop").val() != "") {
             betragnr = parseInt($("#unterop").val());
+            if (betragnr<0) {
+				betragnr = betragnr * (-1);
+				neg = '-';
+			}
             betragstrg = betragnr.toString();
-            if (betragstrg.length > 6)  betragtxt = betragstrg.substring(0, betragstrg.length-6)+"."+betragstrg.substring(betragstrg.length-6, betragstrg.length-3)+"."+betragstrg.substring(betragstrg.length-3, betragstrg.length);
-            else if (betragstrg.length > 3) betragtxt = betragstrg.substring(0, betragstrg.length-3)+"."+betragstrg.substring(betragstrg.length-3, betragstrg.length);
-            else betragtxt = betragstrg;
+            if (betragstrg.length > 6)  betragtxt = neg+betragstrg.substring(0, betragstrg.length-6)+"."+betragstrg.substring(betragstrg.length-6, betragstrg.length-3)+"."+betragstrg.substring(betragstrg.length-3, betragstrg.length);
+            else if (betragstrg.length > 3) betragtxt = neg+betragstrg.substring(0, betragstrg.length-3)+"."+betragstrg.substring(betragstrg.length-3, betragstrg.length);
+            else betragtxt = neg+betragstrg;
             var betragges = "Sie haben angegeben, dass der Betrag schätzungsweise über "+betragwaehr+" "+betragtxt+" liegt.";
         }
         //KATEGORIE GENANNT
@@ -345,7 +367,7 @@ button.onclick = function() {
             }
             if (katmax!="") zwtext = "zwischen Euro "+katmintxt+" und "+katmaxtxt+"";
             else zwtext = "über Euro "+katmintxt+"";
-            var betragges = "Sie haben angegeben, dass der Betrag schätzungsweise "+zwtext+" (Kategorie: "+values["kategorie"]+") liegt angegeben.";
+            var betragges = "Sie haben angegeben, dass der Betrag schätzungsweise "+zwtext+" (Kategorie: "+values["kategorie"]+") liegt.";
         }
         //NICHTSGENANNT
         else {
